@@ -26,10 +26,6 @@ class Dbobject(object):
                                                 filter)
         return cls.get_by_sql(query, *args)
 
-    @classmethod
-    def get_by_id(cls, id):
-        return cls.get_by_filter("id = %s", id)[0]
-
     @classmethod
     def get_all(cls):
         return cls.get_by_filter("1 = 1")
@@ -44,32 +40,6 @@ class Dbobject(object):
         else:
             self.insert()
 
-    @classmethod
-    def create(cls, *args, **kwargs):
-
-        empty_fields = set(cls.fieldnames)
-        field_values = {}
-
-        for key, value in kwargs.iteritems():
-            if key not in cls.fieldnames:
-                raise InvalidFieldName
-            else:
-                empty_fields -= set([key])
-                field_values[key] = value
-
-        for key in empty_fields:
-            field_values[key] = None
-
-        query = "INSERT INTO %s (%s) VALUES (%s)" % (
-                                       cls.tablename,
-                                       ', '.join(field_values.keys()),
-                                       ', '.join(['%s'] * len(cls.fieldnames)))
-
-        g.cur.execute(query, field_values.values())
-        g.con.commit()
-        return cls.get_by_id(get_last_inserted_id())
-
-
     def insert(self):
         query = "INSERT INTO %s (%s) VALUES (%s)" % (
                                        self.tablename,
@@ -102,6 +72,76 @@ class Dbobject(object):
         g.cur.execute(query, [self.id])
 
 
-def get_last_inserted_id():
-    g.cur.execute("""SELECT last_insert_id()""")
-    return g.cur.fetchone()[0]
+class MySQLObject(Dbobject):
+    
+    @staticmethod
+    def get_last_inserted_id():
+        g.cur.execute("""SELECT last_insert_id()""")
+        return g.cur.fetchone()[0]
+
+    @classmethod
+    def get_by_id(cls, id):
+        return cls.get_by_filter("id = %s", id)[0]
+
+    @classmethod
+    def create(cls, *args, **kwargs):
+
+        empty_fields = set(cls.fieldnames)
+        field_values = {}
+
+        for key, value in kwargs.iteritems():
+            if key not in cls.fieldnames:
+                raise InvalidFieldName
+            else:
+                empty_fields -= set([key])
+                field_values[key] = value
+
+        for key in empty_fields:
+            field_values[key] = None
+
+        query = "INSERT INTO %s (%s) VALUES (%s)" % (
+                                       cls.tablename,
+                                       ', '.join(field_values.keys()),
+                                       ', '.join(['%s'] * len(cls.fieldnames)))
+
+        g.cur.execute(query, field_values.values())
+        g.con.commit()
+        return cls.get_by_id(cls.get_last_inserted_id())
+
+
+class SQLiteObject(Dbobject):
+
+    @staticmethod
+    def get_last_inserted_id():
+        g.cur.execute("""SELECT last_insert_rowid()""")
+        return g.cur.fetchone()[0]
+
+    @classmethod
+    def get_by_id(cls, id):
+        return cls.get_by_filter("id = %s" % id)[0]
+
+
+    @classmethod
+    def create(cls, *args, **kwargs):
+
+        empty_fields = set(cls.fieldnames)
+        field_values = {}
+
+        for key, value in kwargs.iteritems():
+            if key not in cls.fieldnames:
+                raise InvalidFieldName
+            else:
+                empty_fields -= set([key])
+                field_values[key] = value
+
+        for key in empty_fields:
+            field_values[key] = None
+
+        query = "INSERT INTO %s (%s) VALUES (%s)" % (
+                                       cls.tablename,
+                                       ', '.join(field_values.keys()),
+                                       ', '.join(['?'] * len(cls.fieldnames)))
+
+        g.cur.execute(query, field_values.values())
+        g.con.commit()
+        return cls.get_by_id(cls.get_last_inserted_id())
